@@ -43,10 +43,15 @@ class User(AbstractUser, BadiModel):
     token = models.ForeignKey(Token, null=True, blank=True, verbose_name=_('Token'), related_name='user',
                               on_delete=models.SET_NULL)
     amount = models.BigIntegerField(default=0, blank=True, verbose_name=_('Amount'))
+    last_action = models.DateTimeField(blank=True, null=True, verbose_name='Last Action')
 
     def __str__(self):
         return self.first_name + " " + self.last_name
 
+    def update_action(self):
+        self.last_action = datetime.now()
+        self.save()
+
     @staticmethod
     def admins():
         return User.objects.filter(is_admin=True)
@@ -68,6 +73,10 @@ class User(AbstractUser, BadiModel):
     def get_form_fields(cls, action, *args):
         if action == 'member_create':
             return ['username', 'password', 'first_name', 'picture', 'last_name', 'is_admin', 'mobile_number']
+        if action == 'member_update':
+            return ['username', 'password', 'first_name', 'picture', 'last_name', 'is_admin', 'mobile_number']
+        if action == 'member_self_update':
+            return ['username', 'password', 'first_name', 'picture', 'last_name', 'is_admin', 'mobile_number']
         return ['first_name', 'last_name', 'mobile_number', 'picture']
 
     @classmethod
